<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:eanucc="urn:ean.ucc:2"
                 version="1.0">

<xsl:template name="listOfStrings">
  <!--single string-->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent">
    <xsl:value-of select="."/>
    <xsl:if test="position() != last()">, </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="listOfStringsOnePerLine">
  <!--single string-->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent">
    <xsl:value-of select="."/>
    <xsl:if test="position() != last()"><br/> </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="xsdBoolean">
  <!--single string-->
  <!--this does not handle values like 00, 01 -->
  <xsl:param name="boolean" />

  <xsl:choose>
    <xsl:when test="$editvalue='true'">
      <xsl:call-template name="showvalue"><xsl:with-param name="currentnode" select="$boolean" /></xsl:call-template>    
    </xsl:when>
    <xsl:otherwise>
      <xsl:choose>
        <xsl:when test="$boolean='1'">yes</xsl:when>
        <xsl:when test="$boolean='true'">yes</xsl:when>
        <xsl:when test="$boolean='0'">no</xsl:when>
        <xsl:when test="$boolean='false'">no</xsl:when>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="xsdDate">
  <!--single string-->
  <!--e.g. 2001-06-28T12:13:14-->
  <!--this does not handle years more than 4 digits-->
  <xsl:param name="date" />
  <xsl:choose>
    <xsl:when test="$editvalue='true'">
      <xsl:call-template name="showvalue"><xsl:with-param name="currentnode" select="$date" /></xsl:call-template>    
    </xsl:when>
    <xsl:otherwise>


  <xsl:variable name="month" select="substring($date,6,2)"/>
  <xsl:variable name="day" select="substring($date,9,2)"/>
  <xsl:variable name="year" select="substring($date,1,4)"/>
  <xsl:variable name="time" select="substring-after($date,'T')"/>
  <xsl:choose>
    <xsl:when test="$month='01'">January <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='02'">February <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='03'">March <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='04'">April <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='05'">May <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='06'">June <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='07'">July <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='08'">August <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='09'">September <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='10'">October <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='11'">November <xsl:value-of select="$day"/>, </xsl:when>
    <xsl:when test="$month='12'">December <xsl:value-of select="$day"/>, </xsl:when>
  </xsl:choose>
  <xsl:value-of select="$year"/>
  <xsl:text> </xsl:text>
  <xsl:value-of select="$time"/>
    </xsl:otherwise>
  </xsl:choose>
  
</xsl:template>

<xsl:template name="formatNodeName">
  <!--single string-->
  <xsl:param name="node" />
  <xsl:variable name="name" select="local-name($node)"/>
  <!-- capitalize the first letter -->
  <xsl:variable name="firstLet" select="substring($name,1,1)"/>
  <xsl:value-of select="translate($firstLet, 'abcdefghijklmnopqrstuvwxyz', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
   <xsl:call-template name="formatNodeNameString">
     <xsl:with-param name="restOfString" select="substring($name,2)" />
   </xsl:call-template>
</xsl:template>

<xsl:template name="formatNodeNameString">
  <!--single string-->
  <xsl:param name="restOfString" />
  <xsl:variable name="firstLet" select="substring($restOfString,1,1)"/>
  <xsl:choose>
  <xsl:when test="$firstLet = 'A' or $firstLet = 'B' or $firstLet = 'C' or
                  $firstLet = 'D' or $firstLet = 'E' or $firstLet = 'F' or
                  $firstLet = 'G' or $firstLet = 'H' or $firstLet = 'I' or
                  $firstLet = 'J' or $firstLet = 'K' or $firstLet = 'L' or
                  $firstLet = 'M' or $firstLet = 'N' or $firstLet = 'O' or
                  $firstLet = 'P' or $firstLet = 'Q' or $firstLet = 'R' or
                  $firstLet = 'S' or $firstLet = 'T' or $firstLet = 'U' or
                  $firstLet = 'V' or $firstLet = 'W' or $firstLet = 'X' or
                  $firstLet = 'Y' or $firstLet = 'Z'
  "><xsl:value-of select="concat(' ',$firstLet)"/></xsl:when>
  <xsl:otherwise><xsl:value-of select="$firstLet"/></xsl:otherwise>
  </xsl:choose>
  <xsl:if test="string-length($restOfString) > 1">
     <xsl:call-template name="formatNodeNameString">
       <xsl:with-param name="restOfString" select="substring($restOfString,2)" />
     </xsl:call-template>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>
