<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                exclude-result-prefixes="xsi" version="1.0">
  <xsl:template name="XsiTypeInformation">
     <xsl:param name="node" />
      <xsl:if test="$node/@xsi:type">
        <!--if node has an 'xsi:type attribute' output the type information-->
          <xsl:variable name="xsiType" select="$node/@xsi:type"/>
          <xsl:variable name="prefix" select="substring-before($xsiType,':')"/>
        [ <xsl:value-of select="$prefix"/> ]
       </xsl:if>
  </xsl:template>

  <xsl:template name="Table5Cols">
    <col class="indent"/><col class="label"/><col class="value"/><col class="label"/><col class="value"/>
  </xsl:template>

  <xsl:template name="Table2Cols">
    <col class="indent"/><col/>
  </xsl:template>

 <xsl:template name="SubsectionWithSimpleChildren">
 <!-- creates a subsection whose title is the element name, and whose children are all simple properties -->
  <xsl:param name="parent" />
  <xsl:param name="tableClass" />
  <xsl:param name="headSuffix" />
   <tr>
     <xsl:if test="$tableClass = 'subSection'">
      <td/>
     </xsl:if>
     <td colspan="5">
       <table>
         <xsl:attribute name="class"><xsl:value-of select="$tableClass"/></xsl:attribute>
         <xsl:call-template name="Table5Cols"/>
         <tr>
           <th colspan="5">
             <xsl:call-template name="formatNodeName">
               <xsl:with-param name="node" select="$parent" />
             </xsl:call-template>
             <xsl:value-of select="$headSuffix"/>
           </th>
         </tr>
         <xsl:call-template name="SimpleChildren">
           <xsl:with-param name="children" select="$parent/*|$parent/@*" />
         </xsl:call-template>
       </table>
     </td>
   </tr>
</xsl:template>

 <xsl:template name="SimpleChildren">
  <xsl:param name="children" />
  <xsl:for-each select="$children">
    <xsl:variable name="pos" select="position()"/>
    <xsl:if test="position() mod 2 = 1">
      <tr>
         <td/>
         <xsl:call-template name="SimpleChildPair">
           <xsl:with-param name="childpair" select=".|$children[$pos + 1]" />
         </xsl:call-template>
      </tr>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="SimpleChildPair">
  <xsl:param name="childpair" />
  <xsl:for-each select="$childpair">
     <xsl:call-template name="SimpleChild">
       <xsl:with-param name="child" select="." />
     </xsl:call-template>
  </xsl:for-each>
</xsl:template>

<xsl:template name="SimpleChild">
  <xsl:param name="child" />
  <xsl:param name="nameOverride" />
  <th class="head4">
     <xsl:choose>
       <xsl:when test="$nameOverride">
         <xsl:value-of select="$nameOverride"/>
       </xsl:when>
       <xsl:when test="name($child) = 'gtin'">GTIN</xsl:when>
       <xsl:otherwise>
         <xsl:call-template name="formatNodeName">
           <xsl:with-param name="node" select="$child" />
         </xsl:call-template>
       </xsl:otherwise>
     </xsl:choose>
  </th>
  <td>
     <xsl:apply-templates select="."/>
  </td>
</xsl:template>

 <xsl:template match="extension">
    <!--section with properties-->
    <tr>
      <td colspan="4">
        <table class="section">
         <xsl:call-template name="Table5Cols"/>
          <tr>
            <th colspan="5">Context-Specific Extensions</th>
          </tr>
          <xsl:for-each select="*">
           <xsl:call-template name="ExtensionElement">
             <xsl:with-param name="parent" select="." />
           </xsl:call-template>
          </xsl:for-each>
        </table>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="*">
    <table>
      <tr>
        <td width="30%" class="tagName">
    <xsl:value-of select="name()"/>
        </td>
        <td width="70%" class="textValue">
          <xsl:call-template name="showvalue"><xsl:with-param name="currentnode" select="." /></xsl:call-template>    
        
        </td>
      </tr>        
    <xsl:for-each select="@*">
      <tr>
        <td class="indent">
        </td>
        <td class="attributeName">
          <xsl:value-of select="name()"/>
        </td>
        <td class="attributeValue">
          <xsl:call-template name="showattribute"><xsl:with-param name="currentnode" select="." /></xsl:call-template>    
        </td>
      </tr>
    </xsl:for-each>
    </table>
  </xsl:template>


  <xsl:template name="ExtensionElement">
    <!--row with properties-->
    <!-- this template is makes parent elements headers and child elements fields.
    It has some klugy special handling for elements of type MeasurementValue or Amount
    if there are more than 2 levels of extensions, it won't be very pretty -->
    <xsl:param name="parent"/>
    <xsl:choose>
    <xsl:when test="$parent/child::* and local-name($parent/child::*) != 'measurementValue'">
      <tr>
        <th colspan="5">{<xsl:value-of select="namespace-uri()"/>}
         <xsl:call-template name="formatNodeName">
           <xsl:with-param name="node" select="." />
         </xsl:call-template></th>
      </tr>
      <xsl:for-each select="$parent/*">
       <xsl:call-template name="ExtensionElement">
         <xsl:with-param name="parent" select="." />
       </xsl:call-template>
      </xsl:for-each>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <td class="indent"/>
        <th class="head4" colspan="2">
           <xsl:if test="namespace-uri()!=''">
              <xsl:value-of select="namespace-uri()"/>:
           </xsl:if>
           <xsl:call-template name="formatNodeName">
             <xsl:with-param name="node" select="." />
           </xsl:call-template>
        </th>
        <td colspan="2">
          <xsl:choose>
            <xsl:when test="./@currencyISOCode">
             <xsl:call-template name="amount">
               <xsl:with-param name="parent" select="." />
             </xsl:call-template>
            </xsl:when>
            <xsl:when test="./*/@unitOfMeasure">
             <xsl:call-template name="measurementValue">
               <xsl:with-param name="parent" select="*" />
             </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="."/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
    </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>
