<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:eanucc="urn:ean.ucc:2"
                 version="1.0">

<xsl:template name="documentInformation">
  <!--section with properties-->
  <tr>
    <td colspan="4">
       <table class="section">
         <xsl:call-template name="Table5Cols"/>
         <tr>
           <th colspan="5">Document Information</th>
         </tr>
        <xsl:call-template name="SimpleChildren">
          <xsl:with-param name="children" select="@creationDate|@lastUpdateDate|
                   @contentVersion|@documentStructureVersion|@documentStatus|@isReload" />
        </xsl:call-template>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="@creationDate|@lastUpdateDate|@begin|@end">
   <xsl:call-template name="xsdDate">
     <xsl:with-param name="date" select="." />
   </xsl:call-template>
</xsl:template>

<xsl:template match="@isReload">
   <xsl:call-template name="xsdBoolean">
     <xsl:with-param name="boolean" select="." />
   </xsl:call-template>
</xsl:template>


<xsl:template name="responseInformation">
  <!--section with properties-->
  <tr>
    <td colspan="4">
       <table class="section">
         <xsl:call-template name="Table5Cols"/>
         <tr>
           <th colspan="5">Response Information</th>
         </tr>
        <xsl:call-template name="SimpleChildren">
          <xsl:with-param name="children" select="@responseStatus" />
        </xsl:call-template>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template name="CommunicationChannel">
  <!--single string with multiple values, e.g. phone: 555-1212, email: xx@x.org -->
  <xsl:param name="channels" />
  <xsl:for-each select="$channels">
    <xsl:value-of select="@communicationChannelCode"/>: <xsl:value-of select="@communicationNumber"/>
    <xsl:if test="position() != last()"><br/> </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="addressFormat">
  <!--single string-->
  <xsl:param name="parent" />
  <xsl:value-of select="$parent/streetAddressOne"/>
  <xsl:if test="$parent/streetAddressTwo">
    <br/><xsl:value-of select="$parent/streetAddressTwo"/>
  </xsl:if>
  <xsl:if test="$parent/crossStreet">
    <br/><xsl:value-of select="$parent/crossStreet"/>
  </xsl:if>
  <xsl:if test="$parent/pOBoxNumber">
    <br/>PO Box <xsl:value-of select="$parent/pOBoxNumber"/>
  </xsl:if>
  <br/><xsl:value-of select="$parent/city"/>, 
    <xsl:if test="$parent/cityCode"><xsl:value-of select="$parent/cityCode"/>
  </xsl:if>
  <xsl:value-of select="$parent/countyCode"/><xsl:value-of select="$parent/provinceCode"/><xsl:value-of select="$parent/state"/><xsl:text> </xsl:text><xsl:value-of select="$parent/postalCode"/><xsl:text> </xsl:text><xsl:value-of select="$parent/countryISOCode"/>
  <xsl:if test="$parent/geographicalCoordinates">
    <br/><xsl:value-of select="$parent/geographicalCoordinates/latitude"/>,<xsl:text> </xsl:text><xsl:value-of select="$parent/geographicalCoordinates/longitude"/>
  </xsl:if>
</xsl:template>

<xsl:template name="NameAndAddressSection">
  <!--section with properties-->
  <xsl:param name="parent" />
  <xsl:param name="prefix" />
    <tr>
      <td colspan="4">
         <table class="section">
         <xsl:call-template name="Table5Cols"/>
          <tr>
            <th colspan="4"><xsl:value-of select="$prefix"/> Name and Address</th>
          </tr>
          <xsl:call-template name="NameAndAddress">
             <xsl:with-param name="parent" select="$parent" />
          </xsl:call-template>
        </table>
      </td>
    </tr>
</xsl:template>

<xsl:template name="NameAndAddress">
  <!--several rows with properties-->
  <xsl:param name="parent" />
  <tr>
    <td class="indent"/>
    <th class="head4">Name</th>
    <td><xsl:value-of select="$parent/name"/></td>
    <th class="head4" rowspan="3">Address</th>
    <td rowspan="3">
      <xsl:call-template name="addressFormat">
         <xsl:with-param name="parent" select="$parent" />
      </xsl:call-template>
    </td>
  </tr>
  <xsl:call-template name="SimpleChildren">
    <xsl:with-param name="children" select="$parent/languageOfTheParty" />
  </xsl:call-template>
  <xsl:call-template name="SimpleChildren">
    <xsl:with-param name="children" select="$parent/currency" />
  </xsl:call-template>
</xsl:template>

<xsl:template name="Reference">
  <!--row with properties-->
  <!--used in data tables -->
  <xsl:param name="parent" />
  <xsl:param name="prefix" />
      <tr>
        <td class="indent"/>
        <th class="head4"><xsl:value-of select="$prefix"/> Ref. ID</th>
        <td>
          <xsl:value-of select="$parent/referenceIdentification"/>
        </td>
        <th class="head4">Ref. Date</th>
        <td>
          <xsl:call-template name="xsdDate">
             <xsl:with-param name="date" select="$parent/referenceDate" />
          </xsl:call-template>
        </td>
      </tr>
</xsl:template>


<xsl:template name="TimePeriod">
  <!--one row with two columns-->
  <xsl:param name="parent" />
  <xsl:param name="prefix" />
   <tr>
    <td class="indent"/>
    <th class="head4"><xsl:value-of select="$prefix"/> Begin</th>
    <td>
        <xsl:call-template name="xsdDate">
           <xsl:with-param name="date" select="$parent/@begin" />
        </xsl:call-template>
    </td>
    <th class="head4"><xsl:value-of select="$prefix"/> End</th>
    <td>
        <xsl:call-template name="xsdDate">
           <xsl:with-param name="date" select="$parent/@end" />
        </xsl:call-template>
    </td>
  </tr>
</xsl:template>

<xsl:template name="TimePeriodCompact">
  <!--one string e.g. Oct 4, 2004 to Oct 24, 2004-->
  <xsl:param name="parent" />
  <xsl:if test="$parent/@begin|$parent/@end">
    <xsl:call-template name="xsdDate">
       <xsl:with-param name="date" select="$parent/@begin" />
    </xsl:call-template> to
    <xsl:call-template name="xsdDate">
       <xsl:with-param name="date" select="$parent/@end" />
    </xsl:call-template>
 </xsl:if>
</xsl:template>

<xsl:template name="monetaryAmount">
  <!--single string with multiple values e.g. 10 USD, 5 CHF -->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent/amount">
    <xsl:value-of select="text()"/><xsl:text> </xsl:text><xsl:value-of select="@currencyISOCode"/>
    <xsl:if test="position() != last()">, </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="amount">
  <!--single string, e.g. 10 USD -->
  <xsl:param name="parent" />
  <xsl:value-of select="$parent"/><xsl:text> </xsl:text><xsl:value-of select="$parent/@currencyISOCode"/>
</xsl:template>

<xsl:template name="percentage">
  <!--single string, e.g. 10% -->
  <xsl:param name="parent" />
  <xsl:value-of select="$parent"/><xsl:text> </xsl:text>%
</xsl:template>

<xsl:template name="measurement">
  <!--single string with multiple values, e.g. 10 LB, 3 KG-->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent/measurementValue">
    <xsl:call-template name="measurementValue">
       <xsl:with-param name="parent" select="." />
    </xsl:call-template>
   <xsl:if test="position() != last()">, </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="measurementValue">
  <!--single string, e.g. 10 LB -->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent">
    <xsl:value-of select="text()"/><xsl:text> </xsl:text><xsl:value-of select="@unitOfMeasure"/>
    <xsl:if test="position() != last()">, </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="Descriptions">
  <!--single string containing several descriptions with line breaks -->
  <!--for something of Description type that repeats -->
  <xsl:param name="rows" />
  <xsl:for-each select="$rows">
    <xsl:call-template name="description">
       <xsl:with-param name="parent" select="." />
    </xsl:call-template>
    <xsl:if test="position() != last()"><br/></xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="description">
  <!--single string, e.g. (en-US) this is the description -->
  <xsl:param name="parent" />
  (<xsl:value-of select="$parent/@language"/>)
  <xsl:value-of select="$parent/text|$parent/longText"/>
</xsl:template>

<xsl:template name="textDescription">
  <!--single string with multiple lines, e.g. (en-US) this is the description, (fr) Ceci est... -->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent/description|$parent/longDescription">
    <xsl:call-template name="description">
       <xsl:with-param name="parent" select="." />
    </xsl:call-template>
    <xsl:if test="position() != last()"><br/></xsl:if>
  </xsl:for-each>
</xsl:template>


<xsl:template name="ContactSection">
  <!--section with properties-->
  <xsl:param name="contacts" />
    <tr>
      <td colspan="4">
         <table class="section">
         <xsl:call-template name="Table5Cols"/>
          <tr>
            <th colspan="2">Contacts</th>
          </tr>
          <xsl:call-template name="Contact">
             <xsl:with-param name="parent" select="$contacts" />
          </xsl:call-template>
        </table>
      </td>
    </tr>
</xsl:template>

<xsl:template name="Contact">
  <!--row with properties-->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent">
    <tr>
      <td class="indent"/>
      <th class="head4">Contact <xsl:value-of select="position()"/></th>
      <td>
        <xsl:call-template name="description">
           <xsl:with-param name="parent" select="personOrDepartmentName/description" />
        </xsl:call-template>
      </td>
      <th class="head4">Comm. Channels</th>
      <td>
        <xsl:call-template name="CommunicationChannel">
           <xsl:with-param name="channels" select="communicationChannel" />
        </xsl:call-template>
      </td>
    </tr>
  </xsl:for-each>
</xsl:template>

</xsl:stylesheet>
