<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:eanucc="urn:ean.ucc:2"
                 version="1.0">

<xsl:template name="partyIdentificationSection">
  <!--section with properties-->
  <xsl:param name="parent" />
  <xsl:param name="headPrefix" />
    <tr>
      <td colspan="4">
         <table class="section">
           <xsl:call-template name="Table5Cols"/>
           <tr>
             <th colspan="5"><xsl:value-of select="$headPrefix"/></th>
           </tr>
           <tr>
            <td class="indent"/>
            <th class="head4">Trade Item ID</th>
            <td>
                <xsl:call-template name="partyIdentification">
                   <xsl:with-param name="parent" select="$parent" />
                </xsl:call-template>
            </td>
          </tr>
        </table>
      </td>
    </tr>
</xsl:template>

<xsl:template name="partyIdentification">
  <!--single string-->
  <!--works for party identification and trade item identification-->
  <xsl:param name="parent" />
  <xsl:for-each select="$parent/gtin|$parent/alternateTradeItemIdentification|$parent/additionalTradeItemIdentification|$parent/gln|$parent/alternatePartyIdentification|$parent/additionalPartyIdentification">
     <!--<xsl:call-template name="XsiTypeInformation">
        <xsl:with-param name="node" select="." />
     </xsl:call-template>-->
    <xsl:call-template name="showvalue"><xsl:with-param name="currentnode" select="." /></xsl:call-template><xsl:call-template name="showattribute"><xsl:with-param name="currentnode" select="@value" /></xsl:call-template>    
    <xsl:if test="@type">
      (<xsl:value-of select="@type"/>)
    </xsl:if>
    <xsl:if test="position() != last()">, </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template name="entityIdentification">
  <!--two columns-->
  <!--used in header rows for transaction, command, document -->
  <xsl:param name="parent" />
  <th class="value">Creator ID =
      <xsl:call-template name="showvalue"><xsl:with-param name="currentnode" select="$parent/uniqueCreatorIdentification" /></xsl:call-template>    
  </th>
  <th class="value">Content Owner =
      <xsl:call-template name="partyIdentification">
         <xsl:with-param name="parent" select="$parent/contentOwner" />
      </xsl:call-template>
  </th>
</xsl:template>

<xsl:template name="entityIdentificationSection">
  <!--section with properties-->
  <xsl:param name="parent" />
  <xsl:param name="headPrefix" />
    <tr>
      <td colspan="4">
         <table class="section">
           <xsl:call-template name="Table5Cols"/>
           <tr>
             <th colspan="5"><xsl:value-of select="$headPrefix"/></th>
           </tr>
          <xsl:call-template name="entityIdentificationRow">
             <xsl:with-param name="parent" select="$parent" />
             <xsl:with-param name="headPrefix" select="''" />
          </xsl:call-template>
        </table>
      </td>
    </tr>
</xsl:template>

<xsl:template name="entityIdentificationRow">
  <!--row with properties-->
  <!--used in data tables -->
  <xsl:param name="parent" />
  <xsl:param name="headPrefix" />
      <tr>
        <td class="indent"/>
        <th class="head4"><xsl:value-of select="$headPrefix"/>Creator ID</th>
        <td>
          <xsl:call-template name="showvalue"><xsl:with-param name="currentnode" select="$parent/uniqueCreatorIdentification" /></xsl:call-template>    
        </td>
        <th class="head4">Content Owner</th>
        <td>
          <xsl:call-template name="partyIdentification">
             <xsl:with-param name="parent" select="$parent/contentOwner" />
          </xsl:call-template>
        </td>
      </tr>
</xsl:template>

<xsl:template name="typedEntityIdentificationRow">
  <!--row with properties-->
  <!--used in data tables -->
  <xsl:param name="parent" />
  <xsl:param name="headPrefix" />
      <xsl:call-template name="entityIdentificationRow">
         <xsl:with-param name="parent" select="$parent/entityIdentification" />
         <xsl:with-param name="headPrefix" select="$headPrefix" />
      </xsl:call-template>
      <tr>
        <td class="indent"/>
        <th class="head4">Entity Type</th>
        <td>
          <xsl:value-of select="$parent/@entityType"/>
        </td>
      </tr>
</xsl:template>

<xsl:template name="DocumentIdentifier">
  <!--section with properties-->
  <xsl:param name="parent" />
  <xsl:param name="headPrefix" />
    <tr>
      <td colspan="4">
         <table class="section">
           <xsl:call-template name="Table5Cols"/>
           <tr>
             <th colspan="5"><xsl:value-of select="$headPrefix"/> Document Identification</th>
           </tr>
            <!-- kluge to handle hierarchy list -->
           <xsl:call-template name="SimpleChildren">
             <xsl:with-param name="children" select="$parent/../quantity|$parent/@contentVersion" />
           </xsl:call-template>
          <xsl:if test="$parent/typedEntityIdentification">
            <xsl:call-template name="typedEntityIdentificationRow">
               <xsl:with-param name="parent" select="$parent/typedEntityIdentification" />
               <xsl:with-param name="headPrefix" select="''" />
            </xsl:call-template>
          </xsl:if>
           <xsl:call-template name="SimpleChildren">
             <xsl:with-param name="children" select="$parent/partyIdentification" />
           </xsl:call-template>
           <xsl:call-template name="SimpleChildren">
             <xsl:with-param name="children" select="$parent/tradeItemIdentification" />
           </xsl:call-template>
        </table>
      </td>
    </tr>
</xsl:template>

<xsl:template name="DocumentIdentifierList">
  <!--section with subsections-->
  <xsl:param name="rows" />
  <xsl:param name="head" />
  <tr>
    <td colspan="4">
      <table class="section">
        <xsl:call-template name="Table2Cols"/>
        <tr>
          <th colspan="2"><xsl:value-of select="$head"/></th>
        </tr>
        <tr>
          <td/>
          <td>
            <table>
              <tr>
                <td>
                  <xsl:for-each select="$rows">
                    <xsl:call-template name="DocumentIdentifier">
                       <xsl:with-param name="parent" select="." />
                    </xsl:call-template>
                  </xsl:for-each>
                </td>
              </tr>
           </table>
          </td>
        </tr>
     </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="partyIdentification|tradeItemIdentification|seller|buyer|billTo|shipTo|shipFrom|buyersBank|sellersBank|remit-to|remit-toBank">
   <xsl:call-template name="partyIdentification">
     <xsl:with-param name="parent" select="." />
   </xsl:call-template>
</xsl:template>

</xsl:stylesheet>
